@@ -3,11 +3,6 @@
 from django.conf import settings
 
 
-_correlation_function = getattr(settings, 'CQRS', {}).get('master', {}).get('correlation_function')
-if _correlation_function and (not callable(_correlation_function)):
-    raise AttributeError('CQRS correlation_function must be callable.')
-
-
 def get_correlation_id(signal_type, cqrs_id, instance_pk, queue):
     """
     :param signal_type: Type of the signal for this message.
@@ -18,5 +13,6 @@ def get_correlation_id(signal_type, cqrs_id, instance_pk, queue):
     :param queue: Queue to synchronize, defaults to None
     :type queue: str, optional
     """
-    if _correlation_function:
-        return _correlation_function(signal_type, cqrs_id, instance_pk, queue)
+    correlation_func = settings.CQRS.get('master', {}).get('correlation_function')
+    if correlation_func:
+        return correlation_func(signal_type, cqrs_id, instance_pk, queue)
